
'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n != 1);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(Om det l\u00e4mnas blankt, kommer \u00e4garen bli admin)",
    "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
    "(at least {placeholder} characters)": "(\u00e5tminstone {placeholder} tecken)",
    "(current notification)": "(aktuellt systemmeddelande)",
    "(current version)": "(nuvarande version)",
    "1 Year": "1 \u00c5r",
    "1 cell copied": "1 cell copied",
    "1 filter": "1 filtrering",
    "1 hidden property": "1 hidden property",
    "1 month ago": "1 m\u00e5nad sedan",
    "1 preset hidden property": "1 preset hidden property",
    "1 record selected": "1 record selected",
    "1 row is copied.": "1 row is copied.",
    "1 sort": "1 sortering",
    "1 week ago": "1 vecka sedan",
    "3 days ago": "3 dagar sedan",
    "30 Days": "30 Dagar",
    "7 Days": "7 Dagar",
    "A file is being uploaded. Are you sure you want to leave this page?": "En fil h\u00e5ller p\u00e5 att laddas upp. \u00c4r du s\u00e4ker p\u00e5 att du vill l\u00e4mna denna sida?",
    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "En fil med namnet {upload_file_link} \u00e4r uppladdat till {uploaded_link}.",
    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
    "A file with the same name already exists in this folder.": "En fil med samma namn existerar i denna mapp.",
    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
    "API Token": "API Token",
    "API token is copied to the clipboard.": "API token \u00e4r kopierad till urklipp.",
    "About": "Om",
    "About Us": "Om Oss",
    "Abuse Content": "Missbruksinneh\u00e5ll",
    "Abuse Reports": "Missbruksrapporter",
    "Abuse Type": "Missbrukstyp",
    "Abuse report added": "Abuse report added",
    "Accept": "Acceptera",
    "Accepted": "Accepterad",
    "Accepted at": "Accepterad vid",
    "Accepter": "Accepteraren",
    "Access Log": "Accesslog",
    "Accurate to minute": "Accurate to minute",
    "Action": "Funktion",
    "Actions": "Funktioner",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Aktivera anv\u00e4ndare direkt efter registrering. Om den inte \u00e4r markerad s\u00e5 beh\u00f6ver anv\u00e4ndaren bli aktiverad av administrat\u00f6r eller via aktiveringsmejl",
    "Activated": "Aktiverad",
    "Activated Users": "Aktiverade Anv\u00e4ndare",
    "Active": "Aktiv",
    "Active Users": "Aktiva Anv\u00e4ndare",
    "Activities": "Aktiviteter",
    "Add": "L\u00e4gg till",
    "Add Admin": "L\u00e4gg till Admin",
    "Add Institution": "L\u00e4gg till Institution",
    "Add Library": "L\u00e4gg till bibliotek",
    "Add Member": "L\u00e4gg till medlem",
    "Add Organization": "L\u00e4gg till Organisation",
    "Add Terms and Conditions": "L\u00e4gg till villkor",
    "Add User": "L\u00e4gg till anv\u00e4ndare",
    "Add Wiki": "L\u00e4gg till Wiki",
    "Add admin": "L\u00e4gg till admin",
    "Add auto expiration": "L\u00e4gg till automatisk utg\u00e5ngsdatum",
    "Add cover": "Add cover",
    "Add custom permission": "Add custom permission",
    "Add filter": "L\u00e4gg till filtrering",
    "Add group": "Add group",
    "Add group member": "L\u00e4gg till gruppmedlem",
    "Add icon": "Add icon",
    "Add institution": "L\u00e4gg till institution",
    "Add members": "L\u00e4gg till medlemmar",
    "Add new notification": "Skapa nytt systemmeddelande",
    "Add option": "Add option",
    "Add password protection": "L\u00e4gg till l\u00f6senordsskydd",
    "Add permission": "Add permission",
    "Add sort": "L\u00e4gg till sortering",
    "Add user": "L\u00e4gg till anv\u00e4ndare",
    "Add view": "Add view",
    "Added": "Tillagd",
    "Added user {user}": "Lade till anv\u00e4ndare {user}",
    "Admin": "Administrera",
    "Admin Login Logs": "Admin Login Loggar",
    "Admin Logs": "Admin-loggar",
    "Admin Operation Logs": "Admin \u00c5tg\u00e4rdsloggar",
    "Admin access": "Adminn \u00e5tkomst",
    "Admins": "Administrat\u00f6rer",
    "Advanced": "Advanced",
    "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.": "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.",
    "All": "Alla",
    "All Groups": "Alla grupper",
    "All Notifications": "Alla systemmeddelanden",
    "All Public Links": "Alla Publika L\u00e4nkar",
    "All comments": "Alla kommentarer",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Till\u00e5t nya anv\u00e4ndarregistreringar. Kryssa ur f\u00f6r att hindra att vem som helst skapar ett nytt konto.",
    "An integer that is greater than 0 or equal to -2.": "En siffra som \u00e4r st\u00f6rre \u00e4n 0 eller lika med -2.",
    "An integer that is greater than or equal to 0.": "En siffra som \u00e4r st\u00f6rre \u00e4n eller lika med 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "En intern l\u00e4nk \u00e4r en l\u00e4nk till en fil eller mapp som kan \u00f6ppnas av en anv\u00e4ndare med l\u00e4s r\u00e4ttigheter till filen eller mappen.",
    "And": "Och",
    "Anonymous User": "Anonnym anv\u00e4ndare",
    "Another property has this property type": "Another property has this property type",
    "Another user is editing this file!": "Another user is editing this file!",
    "Anyone with the link": "Anyone with the link",
    "App Name": "App Namn",
    "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
    "Are you sure to delete": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort",
    "Are you sure to delete ": "Are you sure to delete ",
    "Are you sure to delete this comment?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort denna kommentar?",
    "Are you sure to delete this reply?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort detta svar?",
    "Are you sure to revoke access of user {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort tilltr\u00e4de f\u00f6r anv\u00e4ndare {placeholder}?",
    "Are you sure you want to clear trash?": "\u00c4r du s\u00e4ker p\u00e5 att du vill t\u00f6mma papperskorgen?",
    "Are you sure you want to delete": "Are you sure you want to delete",
    "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
    "Are you sure you want to delete the notification ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort notifikationen?",
    "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
    "Are you sure you want to delete the selected user(s) ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort valda anv\u00e4ndare?",
    "Are you sure you want to delete the share link?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort delningsl\u00e4nken?",
    "Are you sure you want to delete this page?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort den h\u00e4r sidan?",
    "Are you sure you want to delete {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder}?",
    "Are you sure you want to delete {placeholder} completely?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder} helt?",
    "Are you sure you want to disconnect?": "\u00c4r det s\u00e4ker p\u00e5 att du vill avsluta anslutning?",
    "Are you sure you want to remove {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder}?",
    "Are you sure you want to reset the password of {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill \u00e5terst\u00e4lla l\u00f6senordet f\u00f6r {placeholder}?",
    "Are you sure you want to restore this library?": "\u00c4r du s\u00e4ker att du vill \u00e5terst\u00e4lla denna katalog?",
    "Are you sure you want to restore {placeholder}?": "\u00c4r du s\u00e4ker p\u00e5 att du vill \u00e5terst\u00e4lla {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort admin r\u00e4ttigheter f\u00f6r {placeholder}?",
    "Are you sure you want to set {placeholder} as Admin?": "\u00c4r du s\u00e4ker p\u00e5 att du vill s\u00e4tta {placeholder} som Admin?",
    "Are you sure you want to set {user_placeholder} inactive?": "Are you sure you want to set {user_placeholder} inactive?",
    "Are you sure you want to unlink this device?": "\u00c4r du s\u00e4ker p\u00e5 att du vill avl\u00e4nka enheten?",
    "Are you sure you want to unshare {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill avl\u00e4nka {placeholder}?",
    "At server": "P\u00e5 server",
    "Audio": "Audio",
    "Auth Token created": "Auth Token created",
    "Auth Token deleted": "Auth Token deleted",
    "Auto deletion": "Auto borttagning",
    "Automatically delete files that are not modified within certain days:": "Ta bort filer automatiskt som inte har \u00e4ndrats inom antal dagar:",
    "Avatar": "Avatar",
    "Avatar updated": "Avatar updated",
    "Avatar:": "Avatar:",
    "Back": "Bak\u00e5t",
    "Basic": "Basic",
    "Bell Icon": "Bell Icon",
    "Besides Write permission, user can also share the library.": "Ut\u00f6ver Skriv r\u00e4ttigheter, kan anv\u00e4ndare dela katalogen.",
    "Branding": "Branding",
    "Broken (please contact your administrator to fix this library)": "Trasigt (v\u00e4nligen kontakta din administrat\u00f6r f\u00f6r att laga detta bibliotek)",
    "Broken ({repo_id_placeholder})": "Trasig ({repo_id_placeholder})",
    "By day": "By day",
    "By month": "By month",
    "By name ascending": "P\u00e5 namn stigande",
    "By name descending": "P\u00e5 namn fallande",
    "By quarter": "By quarter",
    "By size ascending": "P\u00e5 storlek stigande",
    "By size descending": "P\u00e5 storlek fallande",
    "By time ascending": "P\u00e5 tid stigande",
    "By time descending": "P\u00e5 tid fallande",
    "By week": "By week",
    "By year": "By year",
    "Can not copy folder %(src)s to its subfolder %(des)s": "Can not copy folder %(src)s to its subfolder %(des)s",
    "Can not move folder %(src)s to its subfolder %(des)s": "Can not move folder %(src)s to its subfolder %(des)s",
    "Cancel": "Avbryt",
    "Cancel All": "Avbryt alla",
    "Cannot move parent page to child page": "Cannot move parent page to child page",
    "Capture information": "Capture information",
    "Capture time": "Capture time",
    "Card": "Kort",
    "Certificate": "Certificate",
    "Change": "\u00c4ndra",
    "Change Password": "Byt L\u00f6senord",
    "Change Password of Library {placeholder}": "\u00c4ndra l\u00f6senord f\u00f6r katalogen {placeholder}",
    "Change cover": "Change cover",
    "Change group to department": "Change group to department",
    "Change to department": "Change to department",
    "Changes": "\u00c4ndringar",
    "Checkbox": "Checkbox",
    "Choose date": "V\u00e4lj datum",
    "Clean": "Rensa",
    "Clean succeeded.": "St\u00e4dning lyckades",
    "Cleaned trash": "Rensat skr\u00e4p",
    "Clear": "Rensa",
    "Clear Trash": "Rensa Papperskorg",
    "Clear files in trash and history\uff1a": "Rensa filer i skr\u00e4pkorgen och historik:",
    "Clear selected": "Clear selected",
    "Clients": "Klienter",
    "Close": "St\u00e4ng",
    "Close (Esc)": "St\u00e4ng (Esc)",
    "Code": "Kod",
    "Collaborator": "Collaborator",
    "Collaborators": "Deltagare",
    "Collapse all": "Collapse all",
    "Color space": "Color space",
    "Comment": "Kommentar",
    "Comment details": "Kommentar detaljer",
    "Comments": "Kommentarer",
    "Community Edition": "Community Edition",
    "Compressed": "Compressed",
    "Configure Seafile": "Configure Seafile",
    "Configure your Identity Provider": "Configure your Identity Provider",
    "Confirm": "Bekr\u00e4fta",
    "Confirm Password": "Bekr\u00e4fta l\u00f6senord",
    "Confirm password": "Confirm password",
    "Connect": "Anslut",
    "Contact Email": "Kontakt Mejladress",
    "Contact Email:": "Kontakt mejladress:",
    "Contact Information": "Kontaktinformation",
    "Contact information is required.": "Kontaktinformation kr\u00e4vs.",
    "Content Scan Records": "Inneh\u00e5ll Skanrapporter",
    "Convert & Export": "Convert & Export",
    "Convert Wiki": "Convert Wiki",
    "Convert to Markdown": "Convert to Markdown",
    "Convert to docx": "Convert to docx",
    "Convert to sdoc": "Convert to sdoc",
    "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
    "Converting, please wait...": "Converting, please wait...",
    "Copied": "Kopierad",
    "Copied link to clipboard": "Copied link to clipboard",
    "Copy": "Kopiera",
    "Copy failed": "Copy failed",
    "Copy link": "Copy link",
    "Copy selected": "Copy selected",
    "Copy selected item(s) to:": "Kopiera valda objekt till:",
    "Copy the IdP's certificate and paste it here. The certificate format is as follows:": "Copy the IdP's certificate and paste it here. The certificate format is as follows:",
    "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.": "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.",
    "Copy {num} items": "Kopiera {num} objekt",
    "Copy {placeholder} to": "Kopiera {placeholder} till",
    "Copyright Infringement": "Upphovsr\u00e4ttsintr\u00e5ng",
    "Count": "Antal",
    "Cover": "Cover",
    "Create": "Skapa",
    "Create At": "Skapad",
    "Create Group": "Skapa grupp",
    "Create Library": "Skapa Katalog",
    "Create Report": "Skapa rapport",
    "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
    "Create a new tag": "Skapa en ny tagg",
    "Created": "Skapad",
    "Created At": "Skapad Av",
    "Created Files": "Skapade Filer",
    "Created draft": "Skapat utkast",
    "Created file": "Skapat fil",
    "Created folder": "Skapat mapp",
    "Created group {group_name}": "Skapade grupp {group_name}",
    "Created library": "Skapade katalog",
    "Created library {library_name} with {owner} as its owner": "Skapade katalog {library_name} med {owner} som \u00e4gare",
    "Created time": "Skapad tid",
    "Created {n} files": "Skapat {n} filer",
    "Creator": "Skapad av",
    "Current Connected Devices": "Nuvarande Anslutna Enheter",
    "Current Library": "Nuvarande Katalog",
    "Current Path: ": "Nuvarande s\u00f6kv\u00e4g",
    "Current Version": "Nuvarande Version",
    "Current page": "Current page",
    "Current password": "Current password",
    "Current password cannot be blank": "Nuvarande l\u00f6senord kan inte vara blank",
    "Current path: ": "Nuvarande s\u00f6kv\u00e4g:",
    "Custom CSS": "Egen CSS",
    "Custom properties": "Custom properties",
    "Custom sharing permissions": "Custom sharing permissions",
    "Customize URL": "Customize URL",
    "DNS TXT Value": "DNS TXT Value",
    "Date": "Datum",
    "Date Invalid.": "Datum Ogiltig.",
    "Day": "Day",
    "Default": "Standard",
    "Delete": "Ta bort",
    "Delete Account": "Ta bort konto",
    "Delete Department": "Ta bort Avdelning",
    "Delete Expired Invitations": "Ta Bort Utg\u00e5ngna Inbjudningar",
    "Delete File": "Ta bort Fil",
    "Delete Folder": "Ta bort Mapp",
    "Delete Group": "Ta bort grupp",
    "Delete Institution": "Ta bort institution",
    "Delete Library": "Ta bort Katalog",
    "Delete Member": "Ta bort medlem",
    "Delete Notification": "Ta bort systemmeddelande",
    "Delete Organization": "Ta bort Organisation",
    "Delete Password": "Delete Password",
    "Delete T&C": "Ta bort T&C",
    "Delete User": "Ta bort anv\u00e4ndare",
    "Delete Users": "Ta bort Anv\u00e4ndare",
    "Delete WebDAV Password": "Delete WebDAV Password",
    "Delete Wiki": "Tabort Wiki",
    "Delete file": "Delete file",
    "Delete files from this device the next time it comes online.": "Ta bort filer fr\u00e5n denna enhet n\u00e4sta g\u00e5ng den kommer online.",
    "Delete folder": "Delete folder",
    "Delete group": "Delete group",
    "Delete page": "Delete page",
    "Delete property": "Delete property",
    "Delete selected": "Delete selected",
    "Delete share links": "Delete share links",
    "Deleted": "Borttagen",
    "Deleted Libraries": "Borttagna Kataloger",
    "Deleted Time": "Borttagen Tid",
    "Deleted directories": "Borttagna kataloger",
    "Deleted draft": "Tagit bort utkast",
    "Deleted file": "Tagit bort fil",
    "Deleted files": "Borttagna filer",
    "Deleted folder": "Tagit bort mapp",
    "Deleted group {group_name}": "Tog bort grupp {group_name}",
    "Deleted library": "Katalog borttagen",
    "Deleted library {library_name}": "Tog bort bibliotek {library_name}",
    "Deleted option": "Deleted option",
    "Deleted user %s": "Deleted user %s",
    "Deleted user {user}": "Tog bort anv\u00e4ndare {user}",
    "Department renamed": "Department renamed",
    "Departments": "Avdelningar",
    "Description": "Beskrivning",
    "Description is required": "Beskrivning kr\u00e4vs",
    "Desktop": "Skrivbord",
    "Detail": "Detaljer",
    "Details": "Detaljer",
    "Device": "Enhet",
    "Device Name": "Enhetsnamn",
    "Device make": "Device make",
    "Device model": "Device model",
    "Devices": "Enheter",
    "Dimensions": "Dimensions",
    "Direct download link": "Direct download link",
    "Direct download link is copied to the clipboard.": "Direkt nedladdningsl\u00e4nk kopierat till urklipp.",
    "Disable Two-Factor Authentication": "Avaktivera tv\u00e5faktorsautentisering",
    "Disconnect": "Avsluta",
    "Discussion": "Diskussion",
    "Display files": "Display files",
    "Do not automatically delete files": "Ta inte bort filer automatiskt",
    "Do you really want to turn off extended properties? Existing properties will all be deleted.": "Do you really want to turn off extended properties? Existing properties will all be deleted.",
    "Document": "Dokument",
    "Document conversion failed.": "Document conversion failed.",
    "Document keywords": "Document keywords",
    "Domain verified": "Domain verified",
    "Don't ignore": "Ignorera inte",
    "Don't keep history": "Spara inte historik",
    "Don't replace": "Byt inte ut",
    "Don't send emails": "Skicka inga mail",
    "Done": "Done",
    "Down": "Ned",
    "Download": "Ladda ner",
    "Download an example file": "Ladda ner en exempelfil",
    "Download and upload": "Ladda ner och ladda upp",
    "Drag and drop files or folders here.": "Dra och sl\u00e4pp filer eller mappar h\u00e4r.",
    "Duplicate": "Duplicate",
    "Duplicate page": "Duplicate page",
    "Edit": "\u00c4ndra",
    "Edit format settings": "Edit format settings",
    "Edit labels": "\u00c4ndra markeringar",
    "Edit metadata properties": "Edit metadata properties",
    "Edit multiple select": "Edit multiple select",
    "Edit on cloud and download": "\u00c4ndra i molnet och ladda ner",
    "Edit on cloud only": "Redigera i molnet enbart",
    "Edit permission": "Edit permission",
    "Edit single select": "Edit single select",
    "Edit succeeded": "\u00c4ndring lyckades",
    "Edit succeeded.": "\u00c4ndring lyckades.",
    "Email": "Email",
    "Email Domain": "Email Domain",
    "Email Notification": "Mailnotis",
    "Email is invalid.": "Mailadress \u00e4r ogiltig.",
    "Email notification updated": "Email notification updated",
    "Emails": "Mailadresser",
    "Emails, separated by ','": "Mejladresser separerade med ','",
    "Emojis": "Emojis",
    "Empty": "Tomt",
    "Enable Two-Factor Authentication": "Aktivera tv\u00e5faktorsautentisering",
    "Enable extended properties": "Enable extended properties",
    "Enable face recognition to identify people in your photos.": "Enable face recognition to identify people in your photos.",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Till\u00e5t system admin till att l\u00e4gga till Villkor, samt att alla anv\u00e4ndare m\u00e5ste acceptera villkoren.",
    "Enable two factor authentication": "Aktivera tv\u00e5stegsautentisering",
    "Enable users to share libraries to any groups in the system.": "Aktivera anv\u00e4ndare till att dela kataloger till alla grupper i systemet.",
    "Encrypt": "Kryptera",
    "Encrypted library": "Krypterat bibliotek",
    "End date": "Slutdatum",
    "Enter characters to start searching": "Ange tecken f\u00f6r att p\u00e5b\u00f6rja s\u00f6kning",
    "Error": "Fel",
    "Errors": "Fel",
    "European": "European",
    "Exact date": "Exact date",
    "Exit Institution Admin": "Avsluta institutionsadmin",
    "Exit Organization Admin": "Avsluta Organisations Admin",
    "Exit System Admin": "L\u00e4mna Systemadmin",
    "Expand all": "Expand all",
    "Expiration": "Utg\u00e5ngsdatum",
    "Expiration days": "Utg\u00e5ngsdatum",
    "Expiration time": "Utg\u00e5ngstid",
    "Expired": "Utg\u00e5ngen",
    "Expired at": "Utg\u00e5ngen vid",
    "Export": "Export",
    "Export Excel": "Exportera Excel",
    "Export as docx": "Export as docx",
    "Export as zip": "Export as zip",
    "Export tags": "Export tags",
    "Exporting": "Exporting",
    "Exporting...": "Exporting...",
    "Exposure time": "Exposure time",
    "Extended properties": "Extended properties",
    "Extension Prompts": "Extension Prompts",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Fil\u00e4ndelser f\u00f6r textfiler kan bli f\u00f6rhandsvisade online. Varje suffix \u00e4r separerade av komma.",
    "Extract file detail": "Extract file detail",
    "Extract file details": "Extract file details",
    "F number": "F number",
    "Face recognition": "Face recognition",
    "Failed": "Misslyckades",
    "Failed imported options": "Failed imported options",
    "Failed to add {email_placeholder}: {error_msg_placeholder}": "Misslyckades att l\u00e4gga till {email_placeholder}: {error_msg_placeholder}",
    "Failed to convert {name}.": "Failed to convert {name}.",
    "Failed to copy %(name)s": "Misslyckades att kopiera %(name)s",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Misslyckades kopiera %(name)s och %(amount)s andra objekt.",
    "Failed to copy %(name)s.": "Misslyckades kopiera %(name)s.",
    "Failed to copy files to another library.": "Misslyckades kopiera filer till en annan katalog.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Misslyckades ta bort %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
    "Failed to delete property": "Failed to delete property",
    "Failed to delete records": "Failed to delete records",
    "Failed to delete {name}": "Misslyckades ta bort {name}",
    "Failed to delete {name} and {n} other items.": "Failed to delete {name} and {n} other items.",
    "Failed to delete {name}.": "Misslyckades ta bort {name}.",
    "Failed to download. The total size of the files exceeded the limit.": "Failed to download. The total size of the files exceeded the limit.",
    "Failed to duplicate page": "Failed to duplicate page",
    "Failed to export. Please check whether the size of table attachments exceeds the limit.": "Failed to export. Please check whether the size of table attachments exceeds the limit.",
    "Failed to extract file details": "Failed to extract file details",
    "Failed to generate description": "Failed to generate description",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Misslyckade ignorera %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
    "Failed to insert property": "Failed to insert property",
    "Failed to modify filter": "Failed to modify filter",
    "Failed to modify group": "Failed to modify group",
    "Failed to modify hidden properties": "Failed to modify hidden properties",
    "Failed to modify people name": "Failed to modify people name",
    "Failed to modify property data": "Failed to modify property data",
    "Failed to modify property order": "Failed to modify property order",
    "Failed to modify records": "Failed to modify records",
    "Failed to modify sort": "Failed to modify sort",
    "Failed to move %(name)s and %(amount)s other item(s).": "Misslyckades flytta %(name)s och %(amount)s andra objekt.",
    "Failed to move %(name)s.": "Misslyckades flytta %(name)s.",
    "Failed to move files to another library.": "Misslyckades att flytta filer till en annan katalog.",
    "Failed to move {name}.": "Misslyckades att flytta {name}.",
    "Failed to rename property": "Failed to rename property",
    "Failed to restore records": "Failed to restore records",
    "Failed to restore {name}": "Failed to restore {name}",
    "Failed to restore {name} and {n} other items": "Failed to restore {name} and {n} other items",
    "Failed to save": "Failed to save",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Misslyckades skicka till {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Misslyckades sluta dela {name}",
    "Failed to upload {file_name}.": "Failed to upload {file_name}.",
    "Failed. Please check the network.": "Misslyckades. Kontrollera n\u00e4tverket.",
    "Favorites": "Favoriter",
    "File": "Fil",
    "File Access": "Filaccess",
    "File Operations": "Fil\u00e5tg\u00e4rder",
    "File Scan": "Fil Scan",
    "File Update": "Filuppdatering",
    "File Upload": "Filuppladdning",
    "File Uploading...": "Filen laddas upp...",
    "File already exists.": "Filen existerar redan.",
    "File collaborators": "File collaborators",
    "File details": "File details",
    "File download is disabled: the share link traffic of owner is used up.": "Filnedladdning \u00e4r avst\u00e4ngt: delningsl\u00e4nktrafiken f\u00f6r anv\u00e4ndaren \u00e4r slut.",
    "File expire time": "File expire time",
    "File extension white list": "File extension white list",
    "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.": "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.",
    "File extensions can only be {placeholder}.": "Fil\u00e4ndelser kan enbart vara {placeholder}.",
    "File is locked by others.": "Filer l\u00e5sta av andra.",
    "File name": "File name",
    "File owner": "File owner",
    "File reviewer": "File reviewer",
    "File size is too large.": "Filstorleken \u00e4r f\u00f6r stor.",
    "File status": "File status",
    "File too large": "File too large",
    "File type": "File type",
    "File {file_link} has a new comment form user {author}.": "Filen {file_link} har en ny kommentar fr\u00e5n anv\u00e4ndaren {author}.",
    "Files": "Filer",
    "Files and folders": "Files and folders",
    "Filter": "Filtrera",
    "Filters": "Filters",
    "Find a tag": "Find a tag",
    "Find modifiers": "Find modifiers",
    "Focal length": "Focal length",
    "Folder": "Mapp",
    "Folder Permission": "Mappr\u00e4ttigheter",
    "Folder does not exist.": "Mapp existerar inte",
    "Force Two-Factor Authentication": "Tvinga Tv\u00e5faktors Autensiering",
    "Force user to change password when account is newly added or reset by admin": "Tvinga anv\u00e4ndare att byta l\u00f6senord n\u00e4r ett konto lagts till eller \u00e5terst\u00e4llts av en administrat\u00f6r.",
    "Force user to use a strong password when sign up or change password.": "Tvinga anv\u00e4ndare att anv\u00e4nda ett starkt l\u00f6senord n\u00e4r ett konto skapas eller l\u00f6senord byts.",
    "Format": "Format",
    "Freeze Document": "Freeze Document",
    "Freeze user account when failed login attempts exceed limit.": "L\u00e5s anv\u00e4ndarkonto n\u00e4r antal misslyckade inloggningar n\u00e5tt en gr\u00e4ns.",
    "Frozen by {name}": "Frozen by {name}",
    "Full screen": "Fullsk\u00e4rm",
    "Gallery": "Gallery",
    "General information": "General information",
    "Generate": "Generera",
    "Generate Link": "Generate Link",
    "Generate description": "Generate description",
    "Generate links in batch": "Generate links in batch",
    "Generate share link": "Generate share link",
    "Germany Russia etc": "Germany Russia etc",
    "Global Address Book": "Global Adresslista",
    "Go to Library": "G\u00e5 till Katalog",
    "Greater than or equal to {minDays_placeholder} days": "St\u00f6rre \u00e4n eller lika med {minDays_placeholder} dagar",
    "Grid view": "Grid view",
    "Group": "Grupp",
    "Group Permission": "Grupp R\u00e4ttigheter",
    "Group Shares": "Group Shares",
    "Group by": "Group by",
    "Group members": "Group members",
    "Grouped by 1 property": "Grouped by 1 property",
    "Groups": "Grupper",
    "Guest": "G\u00e4st",
    "Handled": "Hanterad",
    "Help": "Hj\u00e4lp",
    "Hide": "D\u00f6lj",
    "Hide all": "D\u00f6lj alla",
    "Hide properties": "Hide properties",
    "History": "Historik",
    "History Setting": "Historik Inst\u00e4llning",
    "History Versions": "Versionshistorik",
    "IP": "IP",
    "ISO": "ISO",
    "If notifications have not been read within one hour, they will be sent to your mailbox.": "If notifications have not been read within one hour, they will be sent to your mailbox.",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Om detta \u00e4r p\u00e5slaget kommer desktop-klienten inte kunna synka mappar utanf\u00f6r standard Seafile-mappen.",
    "If you don't have any device with you, you can access your account using backup codes.": "Om du inte har din enhet med dig s\u00e5 kan du komma \u00e5t ditt konto med backup koder.",
    "Ignore": "Ignorera",
    "Ignored": "Ignorerad",
    "Import Users": "Importera Anv\u00e4ndare",
    "Import members": "Import members",
    "Import members from a .xlsx file": "Import members from a .xlsx file",
    "Import options": "Import options",
    "Import sdoc": "Import sdoc",
    "Import tags": "Import tags",
    "Import users": "Importera anv\u00e4ndare",
    "Import users from a .xlsx file": "Importera anv\u00e4ndare fr\u00e5n en .xlsx fil",
    "In progress": "In progress",
    "In review": "In review",
    "Inactive": "Inaktiv",
    "Info": "Info",
    "Institution Admin": "Institutionsadmin",
    "Institutions": "Institutioner",
    "Internal Link": "Intern l\u00e4nk",
    "Internal Server Error": "Internt serverproblem",
    "Internal link has been copied to clipboard": "Intern l\u00e4nk har blivit kopierad till urklipp",
    "Invalid destination path": "Felaktig destinationss\u00f6kv\u00e4g",
    "Invalid filename.": "Felaktigt filnamn.",
    "Invalid filter": "Ogiltig filtrering",
    "Invalid month, should be yyyymm.": "Felaktig m\u00e5nad, ska vara yyyymm.",
    "Invalid regular expression": "Invalid regular expression",
    "Invisible": "Invisible",
    "Invitations": "Inbjudningar",
    "Invite Guest": "Bjud in G\u00e4st",
    "Invite Time": "Inbjudningstid",
    "Invite users": "Invite users",
    "Invited at": "Inbjuden vid",
    "Inviter": "Inbjudaren",
    "Is expired": "Is expired",
    "It is required.": "Det kr\u00e4vs.",
    "It may take some time, please wait.": "Det kan ta en stund, v\u00e4nligen v\u00e4nta.",
    "Keep full history": "Spara full historik",
    "Keep sharing": "Keep sharing",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(importerad)",
    "Label": "Markering",
    "Label Current State": "M\u00e4rk Nuvarande Status",
    "Labels": "Markeringar",
    "Language": "Spr\u00e5k",
    "Language Setting": "Spr\u00e5kinst\u00e4llning",
    "Last Access": "Senast Access",
    "Last Login": "Senast Inloggning",
    "Last Update": "Senaste uppdatering",
    "Last modification": "Sista \u00e4ndring",
    "Last modified by": "Senast \u00e4ndrad av",
    "Last modified time": "Last modified time",
    "Last modifier": "Last modifier",
    "Leave": "L\u00e4mna",
    "Leave Group": "L\u00e4mna Grupp",
    "Leave Share": "L\u00e4mna delning",
    "Leave group": "L\u00e4mna grupp",
    "Leave this page? The system may not save your changes.": "Leave this page? The system may not save your changes.",
    "Less than or equal to {maxDays_placeholder} days": "Mindre \u00e4n eller lika med {maxDays_placeholder} dagar",
    "Libraries": "Kataloger",
    "Library": "Katalog",
    "Library Type": "Katalogstyp",
    "Library can not be shared to owner.": "Katalogen kan inte delas till \u00e4garen.",
    "Limits": "Begr\u00e4nsningar",
    "Link": "L\u00e4nk",
    "Link has been copied to clipboard": "L\u00e4nken har blivit kopierad till urklipp",
    "Linked Devices": "L\u00e4nkade Enheter",
    "Links": "L\u00e4nkar",
    "List view": "List view",
    "List your account in global address book, so that others can find you by typing your name.": "Lista dina konton i den globala adresslistan, s\u00e5 att andra kan hitta dig genom att s\u00f6ka efter ditt namn.",
    "Load all": "Load all",
    "Loading": "Loading",
    "Location": "Lokation",
    "Lock": "L\u00e5s",
    "Log out": "Logga ut",
    "Login": "Logga in",
    "Login ID": "Login ID",
    "Logo updated": "Logo updated",
    "Logs": "Loggar",
    "Long text": "Long text",
    "Manage group members": "Hantera gruppmedlemmar",
    "Manage members": "Manage members",
    "Mark all as read": "Markera alla som l\u00e4sna",
    "Mark all read": "Markera alla l\u00e4sta",
    "Mark as resolved": "Markera som l\u00f6st",
    "Max": "Max",
    "Max number of members": "Max number of members",
    "Member": "Medlem",
    "Members": "Medlemmar",
    "Message": "Meddelande",
    "Message (optional):": "Meddelande (valfritt):",
    "Migrate User": "Migrate User",
    "Mobile": "Mobil",
    "Modification Details": "Detaljer",
    "Modified": "\u00c4ndrad",
    "Modified by": "Modified by",
    "Modified by:": "Modified by:",
    "Modified files": "\u00c4ndrade filer",
    "Modifier": "\u00c4ndrad av",
    "Modify": "\u00c4ndra",
    "Modify includes modify file, move/rename file and folder": "Modify includes modify file, move/rename file and folder",
    "Modify name": "Modify name",
    "Month": "Month",
    "Month:": "M\u00e5nad:",
    "Monthly User Traffic": "M\u00e5nadsvis anv\u00e4ndartrafik",
    "More": "Mer",
    "More operations": "Fler \u00e5tg\u00e4rder",
    "Move": "Flytta",
    "Move selected item(s) to:": "Flytta valda objekt till:",
    "Move {num} items": "Flytta {num} objekt",
    "Move {placeholder} to": "Flytta {placeholder} till",
    "Moved file": "Flyttat fil",
    "Moved folder": "Flyttat mapp",
    "Multiple select": "Multiple select",
    "My Libraries": "Mina Kataloger",
    "My Wikis": "My Wikis",
    "Name": "Namn",
    "Name already exists": "Name already exists",
    "Name cannot be double dots": "Name cannot be double dots",
    "Name cannot be empty": "Name cannot be empty",
    "Name cannot contain backslash": "Name cannot contain backslash",
    "Name cannot contain backtick": "Name cannot contain backtick",
    "Name cannot contain curly braces": "Name cannot contain curly braces",
    "Name cannot contain dots": "Name cannot contain dots",
    "Name cannot contain slash": "Name cannot contain slash",
    "Name is required": "Namn kr\u00e4vs",
    "Name is required.": "Namn kr\u00e4vs.",
    "Name or ID": "Name or ID",
    "Name should be string": "Name should be string",
    "Name should not include '/'.": "Namn ska inte inneh\u00e5lla '/'.",
    "Name updated": "Name updated",
    "Name(optional)": "Namn(valfritt)",
    "Network error": "N\u00e4tverksfel",
    "New": "Ny",
    "New Department": "Ny Avdelning",
    "New Department Library": "Ny Avdelningskatalog",
    "New Excel File": "Ny Excel-fil",
    "New File": "Ny fil",
    "New Folder": "Ny Mapp",
    "New Group": "Ny grupp",
    "New Library": "Ny Katalog",
    "New Markdown File": "Ny Markdown-fil",
    "New Password": "Nytt L\u00f6senord",
    "New Password Again": "Nytt L\u00f6senord Igen",
    "New PowerPoint File": "Ny PowerPoint-fil",
    "New SeaDoc File": "New SeaDoc File",
    "New Sub-department": "Ny Underavdelning",
    "New Word File": "Ny Word-fil",
    "New directories": "Nya kataloger",
    "New file name": "Nytt filnamn",
    "New files": "Nya filer",
    "New folder name": "Nytt mappnamn",
    "New page": "Ny sida",
    "New password": "Nytt l\u00f6senord",
    "New password cannot be the same as old password": "New password cannot be the same as old password",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "Nytt l\u00f6senord har skickats till din mailadress {mail}. V\u00e4nligen kontrollera din maill\u00e5da. Om du inte har f\u00e5tt l\u00f6senordet, v\u00e4nligen kontrollera att din mailadress \u00e4r korrekt konfigurerad.",
    "New password is too short": "Det nya l\u00f6senordet \u00e4r f\u00f6r kort",
    "New passwords don't match": "De nya l\u00f6senorden \u00f6verensst\u00e4mmer inte",
    "New view": "New view",
    "Next": "N\u00e4sta",
    "Next (Right arrow key)": "N\u00e4sta (H\u00f6ger piltangent)",
    "Next modification": "N\u00e4sta \u00e4ndring",
    "No Admin login logs": "Inga Admin login loggar",
    "No Admin operation logs": "Inga Admin \u00e5tg\u00e4rdsloggar",
    "No Wikis": "No Wikis",
    "No changes": "Inga \u00e4ndringar",
    "No collaborators": "No collaborators",
    "No collaborators available": "No collaborators available",
    "No comment yet.": "Inga kommentarer \u00e4nnu.",
    "No connected devices": "Inga anslutna enheter",
    "No deleted libraries": "Inga borttagna kataloger",
    "No favorites": "Inga favoriter",
    "No file": "No file",
    "No file access logs": "Inga fil\u00e5tkomstloggar",
    "No file update logs": "Inga filuppdateringsloggar",
    "No filters": "Inga filtreringar",
    "No folders shared": "Inga mappar delade",
    "No groupings applied to this view.": "No groupings applied to this view.",
    "No groups": "Inga grupper",
    "No guest invitations": "Inga g\u00e4stinbjudningar",
    "No invitations": "Inga inbjudningar",
    "No libraries": "Inga kataloger",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "Inga kataloger har delats direkt med dig. En delad katalog kan delas med fulla eller restriktiva r\u00e4ttigheter. Om du beh\u00f6ver komma \u00e5t en katalog som \u00e4gs av en annan anv\u00e4ndare. S\u00e5 beh\u00f6ver du be anv\u00e4ndaren att dela katalogen med dig.",
    "No libraries have been shared with you": "Inga bibliotek \u00e4r delade med dig",
    "No libraries have been shared with you from other servers.": "Inga kataloger har inte blivit delad med dig fr\u00e5n andra servrar.",
    "No libraries shared": "Inga kataloger delade",
    "No libraries shared with this group": "Inga kataloger delas med denna grupp",
    "No linked devices": "Inga l\u00e4nkade enheter",
    "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "No login logs": "Inga login loggar",
    "No members": "Inga Medlemmar",
    "No more activities": "No more activities",
    "No notifications": "Inga notifikationer",
    "No option": "No option",
    "No options": "No options",
    "No options available": "No options available",
    "No permission logs": "Inga r\u00e4ttighetsloggar",
    "No properties available to be hidden": "No properties available to be hidden",
    "No public libraries": "Inga publika kataloger",
    "No record": "No record",
    "No result": "Inget resultat",
    "No results": "Inga resultat",
    "No results matching": "No results matching",
    "No share links": "Inga delningsl\u00e4nkar",
    "No shared libraries": "Inga delade kataloger",
    "No sorts": "Inga sorteringar",
    "No sync errors": "Inga synkroniseringsfel",
    "No tags": "Inga taggar",
    "No terms and conditions": "Inga villkor",
    "No upload links": "Inga uppladdningsl\u00e4nkar",
    "No version history": "No version history",
    "None": "Ingen",
    "Not allow user to clean library trash": "Not allow user to clean library trash",
    "Not allow user to create encrypted libraries": "Not allow user to create encrypted libraries",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Not: Inst\u00e4llningar via webbgr\u00e4nssnittet \u00e4r sparade i databastabellen (seahub-db/constance_config). De har h\u00f6gre prioritet \u00f6ver inst\u00e4llningar i konfigurationsfiler.",
    "Notification Detail": "Detaljer",
    "Notifications": "Meddelanden",
    "Notifications of file changes": "Notifications of file changes",
    "Number": "Number",
    "Number of days ago": "Number of days ago",
    "Number of days from now": "Number of days from now",
    "Number of days that keep user sign in.": "Antal dagar som anv\u00e4ndaren h\u00e5lls inloggad.",
    "Number of groups": "Antal grupper",
    "Number of links": "Number of links",
    "Number of members": "Antal medlemmar",
    "Off": "Av",
    "Old Password": "Gammalt L\u00f6senord",
    "Old Wikis": "Old Wikis",
    "On": "P\u00e5",
    "One month ago": "One month ago",
    "One month from now": "One month from now",
    "One week ago": "One week ago",
    "One week from now": "One week from now",
    "Online Preview": "Online F\u00f6rhandsvisning",
    "Online Read-Only": "Online L\u00e4s-Endast",
    "Online Read-Only folder": "Online L\u00e4s-Enbart mapp",
    "Online Read-Only library": "Online L\u00e4s-Endast katalog",
    "Online Read-Write": "Online L\u00e4s-Skriv",
    "Online Read-Write folder": "Online L\u00e4s-Skriv mapp",
    "Online Read-Write library": "Online L\u00e4s-Skriva katalog",
    "Online view is not applicable to this file format": "Online-visning \u00e4r inte tillg\u00e4ngligt f\u00f6r detta filformat",
    "Only Show": "Visa Enbart",
    "Only files": "Only files",
    "Only folders": "Only folders",
    "Only keep a period of history:": "Spara endast historiken ",
    "Only pictures": "Only pictures",
    "Only videos": "Only videos",
    "Open file": "Open file",
    "Open file in new tab": "Open file in new tab",
    "Open folder": "Open folder",
    "Open folder in new tab": "Open folder in new tab",
    "Open in new tab": "Open in new tab",
    "Open parent folder": "\u00d6ppna huvudmapp",
    "Open via Client": "\u00d6ppna via Klient",
    "Operation": "\u00c5tg\u00e4rd",
    "Operation succeeded.": "\u00c5tg\u00e4rden lyckades.",
    "Operations": "\u00c5tg\u00e4rder",
    "Optional": "Valfritt",
    "Options imported": "Options imported",
    "Or": "Eller",
    "Organization": "Organisation",
    "Organization Admin": "Organisationsadmin",
    "Organizations": "Organisationer",
    "Original path": "Original path",
    "Other": "Annat",
    "Other Libraries": "Andra Kataloger",
    "Others": "Others",
    "Out of quota.": "Slut p\u00e5 kvoten.",
    "Outdated": "Outdated",
    "Outline": "Kontur",
    "Owned Libraries": "\u00c4gda Kataloger",
    "Owner": "\u00c4gare",
    "Owner can use admin panel in an organization, must be a new account.": "\u00c4gare kan inte anv\u00e4nda adminpanelen i en organisation. M\u00e5ste vara ett nytt konto.",
    "Packaging...": "Paketerar...",
    "Page name": "Page name",
    "Pages": "Sidor",
    "Parent folder": "Parent folder",
    "Password": "L\u00f6senord",
    "Password again": "L\u00f6senord igen",
    "Password cannot be blank": "L\u00f6senordet m\u00e5ste anges",
    "Password is too short": "L\u00f6senordet \u00e4r f\u00f6r kort",
    "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols": "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols",
    "Password removed": "Password removed",
    "Password reset": "Password reset",
    "Password set": "Password set",
    "Password strength": "Password strength",
    "Password updated": "Password updated",
    "Passwords do not match.": "L\u00f6senorden matchar inte.",
    "Passwords don't match": "L\u00f6senorden \u00f6verensst\u00e4mmer inte",
    "Path": "S\u00f6kv\u00e4g",
    "Per 4 hours": "Var fj\u00e4rde timme",
    "Per day": "Varje dag",
    "Per hour": "Per timme",
    "Per week": "Varje vecka",
    "Permission": "Beh\u00f6righet",
    "Permission denied": "\u00c5tkomst nekas",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "\u00c5tkomst nekas. V\u00e4nligen testa {placeholder-left}logga in igen.{placeholder-right}",
    "Permission name": "Permission name",
    "Person image": "Person image",
    "Picture": "Picture",
    "Pictures and videos": "Pictures and videos",
    "Platform": "Plattform",
    "Please check the network.": "Kontrollera n\u00e4tverksanslutningen",
    "Please choose a .xlsx file.": "V\u00e4nligen v\u00e4lj en .xlsx fil.",
    "Please choose an image file.": "V\u00e4nligen ange en bildfil.",
    "Please enter 1 or more character": "V\u00e4nligen ange 1 eller fler tecken",
    "Please enter a new password": "V\u00e4nligen ange det nya l\u00f6senordet",
    "Please enter a non-negative integer": "V\u00e4nligen ange en icke negativ siffra",
    "Please enter a password.": "Please enter a password.",
    "Please enter a positive integer": "V\u00e4nligen ange ett positivt heltal",
    "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
    "Please enter an integer not bigger than {max_number} as number of links.": "Please enter an integer not bigger than {max_number} as number of links.",
    "Please enter days": "V\u00e4nligen ange antal dagar",
    "Please enter password": "V\u00e4nligen ange l\u00f6senordet",
    "Please enter the new password again": "V\u00e4nligen ange det nya l\u00f6senordet igen",
    "Please enter the old password": "V\u00e4nligen ange det gamla l\u00f6senordet",
    "Please enter the password again": "V\u00e4nligen ange l\u00f6senordet igen",
    "Please input at least an email.": "V\u00e4nligen ange minst en e-postadress.",
    "Please select a file": "Please select a file",
    "Please select a library to share.": "V\u00e4lj en katalog att dela.",
    "Please select an expiration time": "Please select an expiration time",
    "Please upload no more than {maxFiles} files at a time.": "V\u00e4nligen ladda inte upp mer \u00e4n {maxFiles} filer \u00e5t g\u00e5ngen.",
    "Preparing to upload...": "F\u00f6rbereder uppladdning...",
    "Preset hide properties": "Preset hide properties",
    "Preview and download": "F\u00f6rhandsgranska och ladda ner",
    "Preview online": "Preview online",
    "Preview only": "F\u00f6rhandsgranska enbart",
    "Previous": "Tidigare",
    "Previous (Left arrow key)": "F\u00f6reg\u00e5ende (V\u00e4nster piltangent)",
    "Print": "Skriv ut",
    "Professional Edition": "Professional Edition",
    "Profile": "Profil",
    "Profile Setting": "Profilinst\u00e4llningar",
    "Properties": "Properties",
    "Property name": "Property name",
    "Publish": "Publicera",
    "Publish Wiki": "Publish Wiki",
    "Published": "Publicerad",
    "Quota": "Kvot",
    "Quota is invalid.": "Kvot \u00e4r inte giltig.",
    "Rate": "Rate",
    "Read-Only": "L\u00e4s enbart",
    "Read-Only folder": "L\u00e4s-Enbart mapp",
    "Read-Only library": "Skrivskyddat bibliotek",
    "Read-Write": "L\u00e4s/Skriv",
    "Read-Write folder": "L\u00e4s-Skriv mapp",
    "Read-Write library": "Skrivbart bibliotek",
    "Really want to delete this group?": "Vill du verkligen ta bort denna grupp?",
    "Really want to delete your account?": "Vill du verkligen ta bort ditt konto? ",
    "Really want to leave this group?": "Vill du verkligen l\u00e4mna denna grupp?",
    "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
    "Refresh": "Uppdatera",
    "Remaining": "\u00c5terst\u00e5r",
    "Remove": "Ta bort",
    "Remove Member": "Ta bort Medlem",
    "Rename": "D\u00f6p om",
    "Rename Department": "Rename Department",
    "Rename File": "D\u00f6p om fil",
    "Rename Folder": "D\u00f6p om Mapp",
    "Rename Group": "D\u00f6p om Grupp",
    "Rename Wiki": "Rename Wiki",
    "Rename file": "Rename file",
    "Rename folder": "Rename folder",
    "Rename group to": "D\u00f6p om grupp till",
    "Rename property": "Rename property",
    "Renamed file": "D\u00f6pt om fil",
    "Renamed folder": "D\u00f6pt om mapp",
    "Renamed library": "D\u00f6pte om katalog",
    "Renamed or Moved files": "Omd\u00f6pta eller flyttade filer",
    "Renaming {name} failed": "\u00c4ndra namnet f\u00f6r {name} misslyckades",
    "Replace": "Byta ut",
    "Replace file {filename}?": "Ers\u00e4tt filen {filename}?",
    "Replacing it will overwrite its content.": "Att byta ut dem kommer skriva \u00f6ver inneh\u00e5llet.",
    "Report Abuse": "Rapportera Missbruk",
    "Reporter": "Rapport\u00f6r",
    "Reports": "Rapporter",
    "Required at least three letters.": "Kr\u00e4vs \u00e5tminstone tre bokst\u00e4ver.",
    "Reset": "\u00c5terst\u00e4ll",
    "Reset Password": "\u00c5terst\u00e4ll L\u00f6senord",
    "Reset WebDAV Password": "Reset WebDAV Password",
    "Reset library password": "\u00c5terst\u00e4ll katalogsl\u00f6senord",
    "ResetPwd": "ResetPwd",
    "Resetting user's password, please wait for a moment.": "\u00c5terst\u00e4ller anv\u00e4ndarens l\u00f6senord, v\u00e4nligen v\u00e4nta.",
    "Resolved comments": "L\u00f6sta kommentarer",
    "Restore": "L\u00e4s tillbaka",
    "Restore Library": "\u00c5terst\u00e4ll Katalog",
    "Restored file": "\u00c5terst\u00e4llt fil",
    "Restored folder": "\u00c5terst\u00e4llt mapp",
    "Restored library": "\u00c5terst\u00e4llt katalog",
    "Restored {name}": "Restored {name}",
    "Restored {name} and {n} other items": "Restored {name} and {n} other items",
    "Resubmit": "Skicka om",
    "Result": "Resultat",
    "Retry": "F\u00f6rs\u00f6k igen",
    "Retry All": "F\u00f6rs\u00f6k igen med Alla",
    "Revoke": "Degradera",
    "Revoke Access": "Ta bort Tilltr\u00e4de",
    "Revoke Admin": "Degradera admin",
    "Role": "Roll",
    "SAML config": "SAML config",
    "SAML config updated": "SAML config updated",
    "Save": "Spara",
    "Save Selected Items": "Save Selected Items",
    "Save as ...": "Spara som ...",
    "Save to:": "Spara till:",
    "Saving...": "Sparar...",
    "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
    "SeaTable integration": "SeaTable integration",
    "Seafile": "Seafile",
    "Search": "S\u00f6k",
    "Search Groups": "S\u00f6k Grupper",
    "Search Libraries": "S\u00f6k Kataloger",
    "Search Organizations": "S\u00f6k Organisationer",
    "Search Users": "S\u00f6k Anv\u00e4ndare",
    "Search collaborator": "S\u00f6k kollegor",
    "Search collaborators": "Search collaborators",
    "Search department": "S\u00f6k efter avdelning",
    "Search files": "Search files",
    "Search files in this library": "S\u00f6k efter filer i denna katalog",
    "Search groups": "S\u00f6k grupper",
    "Search groups by name": "S\u00f6k grupper med namn",
    "Search libraries by name or ID": "Search libraries by name or ID",
    "Search libraries by owner": "S\u00f6k kataloger med \u00e4gare",
    "Search option": "S\u00f6k efter alternativ",
    "Search organizations": "S\u00f6k organisationer",
    "Search property": "Search property",
    "Search users": "S\u00f6k anv\u00e4ndare",
    "Search users...": "S\u00f6k anv\u00e4ndare...",
    "Searching...": "S\u00f6ker...",
    "Select File": "V\u00e4lj Fil",
    "Select a department": "V\u00e4lj en avdelning",
    "Select a user": "V\u00e4lj en anv\u00e4ndare",
    "Select a user as admin": "Select a user as admin",
    "Select all": "Select all",
    "Select an option": "V\u00e4lj ett alternativ",
    "Select collaborators": "Select collaborators",
    "Select libraries to share": "V\u00e4lj kataloger att dela",
    "Select option(s)": "V\u00e4lj alternativ(er)",
    "Select up to 50 files": "Select up to 50 files",
    "Send": "Skicka",
    "Send activation Email after user registration.": "Skicka aktiverings-mejl efter anv\u00e4ndarregistrering.",
    "Send to:": "Skicka till:",
    "Sending new password...": "Skickar nytt l\u00f6senord...",
    "Sending...": "Skickar...",
    "Server": "Server",
    "Server Version: ": "Serverversion: ",
    "Set Admin": "S\u00e4tt admin",
    "Set Contact Email": "S\u00e4tt Kontaktmail",
    "Set Download Rate Limit": "Set Download Rate Limit",
    "Set Login ID": "S\u00e4tt Login ID",
    "Set Name": "S\u00e4tt Namn",
    "Set Password": "S\u00e4tt l\u00f6senord",
    "Set Quota": "S\u00e4tt kvot",
    "Set Upload Rate Limit": "Set Upload Rate Limit",
    "Set WebDAV Password": "Set WebDAV Password",
    "Set max number of members": "S\u00e4tt max antal medlemmar",
    "Set password": "Set password",
    "Set permission": "S\u00e4tt r\u00e4ttigheter",
    "Set permission of {placeholder}": "Set permission of {placeholder}",
    "Set quota": "S\u00e4tt kvot",
    "Set to current": "S\u00e4tt som aktuellt systemmeddelande",
    "Set user contact email": "S\u00e4tt anv\u00e4ndarkontakt mejl",
    "Set user default quota": "Set user default quota",
    "Set user name": "S\u00e4tt anv\u00e4ndarens namn",
    "Set user quota": "S\u00e4tt anv\u00e4ndarkvot",
    "Setting library history is disabled by Admin.": "Inst\u00e4llningen katalogshistorik \u00e4r avst\u00e4ngd av Admin",
    "Settings": "Inst\u00e4llningar",
    "Share": "Dela",
    "Share Admin": "Administrera delningar",
    "Share From": "Dela fr\u00e5n",
    "Share Link": "Dela L\u00e4nk",
    "Share Link Traffic": "Delningsl\u00e4nk Trafik",
    "Share Links": "Delningsl\u00e4nkar",
    "Share To": "Dela med",
    "Share To:": "Dela Till:",
    "Share link download": "Delningsl\u00e4nk nedladdat",
    "Share link is copied to the clipboard.": "Delningsl\u00e4nk \u00e4r kopierat till urklipp",
    "Share link upload": "Delningsl\u00e4nk uppladdat",
    "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.": "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.",
    "Share to group": "Dela till grupp",
    "Share to other server": "Dela till annan server",
    "Share to user": "Dela till anv\u00e4ndare",
    "Shared By": "Delad av",
    "Shared Libraries": "Delade Kataloger",
    "Shared Links": "Delade L\u00e4nkar",
    "Shared by:": "Delas av:",
    "Shared by: ": "Delad av:",
    "Shared from other servers": "Delad fr\u00e5n andra servrar",
    "Shared with all": "Delade med alla",
    "Shared with me": "Delade med mig",
    "Show": "Visa",
    "Show Codes": "Visa Koder",
    "Show all": "Visa alla",
    "Show changes": "Show changes",
    "Side Nav Menu": "Sidomeny",
    "Single select": "Single select",
    "Site name used in email sending": "Sidnamn som anv\u00e4nds i mejlutskick",
    "Site title shown in a browser tab": "Sidtiteln som visas i en webbl\u00e4sartabb",
    "Size": "Storlek",
    "Sort": "Sortera",
    "Sort ascending": "Sort ascending",
    "Sort descending": "Sort descending",
    "Space Used": "Anv\u00e4nt utrymme",
    "Space Used / Quota": "Utrymme Anv\u00e4nt / Kvot",
    "Specific people with email address": "Specific people with email address",
    "Specific users in the team": "Specific users in the team",
    "Star": "Favorit",
    "Start date": "Startdatum",
    "Statistic": "Statistik",
    "Status": "Status",
    "Status: enabled": "Status: aktiverad",
    "Storage": "Utrymme",
    "Storage Backend": "Lagringsyta",
    "Storage Used": "Anv\u00e4nt Utrymme",
    "Style": "Stil",
    "Submit": "OK",
    "Success": "Lyckades",
    "Successfully added label(s) for library {placeholder}": "Lyckades l\u00e4gga till markering(ar) till katalogen {placeholder}",
    "Successfully added {email_placeholder}": "Lyckades l\u00e4gga till {email_placeholder}",
    "Successfully change the group": "Successfully change the group",
    "Successfully changed library password.": "\u00c4ndrade l\u00f6senord f\u00f6r katalogen.",
    "Successfully cleaned all errors.": "Lyckades rensa alla fel.",
    "Successfully cleared trash.": "Lyckades rensa papperskorg.",
    "Successfully converted the file.": "Successfully converted the file.",
    "Successfully copied %(name)s and %(amount)s other items.": "Lyckades kopiera %(name)s och %(amount)s andra filer.",
    "Successfully copied %(name)s and 1 other item.": "Lyckades kopiera %(name)s och 1 annan fil.",
    "Successfully copied %(name)s.": "Lyckades kopiera %(name)s.",
    "Successfully copied files to another library.": "Lyckades kopiera filer till en annan katalog.",
    "Successfully deleted 1 item": "Lyckades ta bort 1 sak",
    "Successfully deleted 1 item.": "Lyckades ta bort 1 sak.",
    "Successfully deleted 1 share link": "Successfully deleted 1 share link",
    "Successfully deleted 1 user.": "Lyckades ta bort 1 anv\u00e4ndare.",
    "Successfully deleted {name}": "Lyckades ta bort {name}",
    "Successfully deleted {name} and {n} other items": "Successfully deleted {name} and {n} other items",
    "Successfully deleted {name} and {n} other items.": "Successfully deleted {name} and {n} other items.",
    "Successfully deleted {name}.": "Lyckades ta bort {name}.",
    "Successfully deleted {number_placeholder} share links": "Successfully deleted {number_placeholder} share links",
    "Successfully deleted {user_number_placeholder} users.": "Lyckades ta bort {user_number_placeholder} anv\u00e4ndare.",
    "Successfully edited labels.": "Lyckades \u00e4ndra markeringar.",
    "Successfully invited %(email) and %(num) other people.": "Lyckades bjuda in %(email) och %(num) andra personer.",
    "Successfully invited %(email).": "Lyckades bjuda in %(email).",
    "Successfully modified permission.": "Lyckades modifiera r\u00e4ttigheter.",
    "Successfully moved %(name)s and %(amount)s other items.": "Lyckades flytta %(name)s och %(amount)s andra filer.",
    "Successfully moved %(name)s and 1 other item.": "Lyckades flytta %(name)s och 1 annan fil.",
    "Successfully moved %(name)s.": "Lyckades flytta %(name)s.",
    "Successfully moved files to another library.": "Lyckades flytta filer till en annan katalog.",
    "Successfully moved {name}.": "Lyckades flytta {name}.",
    "Successfully removed {placeholder}.": "Lyckades ta bort {placeholder}.",
    "Successfully restored the library {library_name}.": "Successfully restored the library {library_name}.",
    "Successfully restored the library.": "Lyckades \u00e5terst\u00e4lla katalogen.",
    "Successfully restored.": "Lyckades \u00e5terst\u00e4lla.",
    "Successfully revoke the admin permission of %s": "Tog bort adminbeh\u00f6righet f\u00f6r %s",
    "Successfully revoked access of user {placeholder}.": "Lyckades ta bort tilltr\u00e4de f\u00f6r anv\u00e4ndare {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Lyckades ta bort adminr\u00e4ttigheter f\u00f6r {placeholder}.",
    "Successfully saved": "Lyckades spara",
    "Successfully sent to {placeholder}": "Lyckades skicka till {placeholder}",
    "Successfully set %s as admin.": "Lyckades s\u00e4tta %s som admin.",
    "Successfully set it.": "Lyckades s\u00e4tta den.",
    "Successfully set library history.": "Satte katalogens historik.",
    "Successfully set quota.": "Lyckades s\u00e4tta kvot.",
    "Successfully starred {library_name_placeholder}.": "{library_name_placeholder} las till favoriter.",
    "Successfully transferred the group.": "Gruppen \u00f6verf\u00f6rd.",
    "Successfully transferred the library.": "Biblioteket \u00f6verf\u00f6rdes.",
    "Successfully unlinked %(name)s.": "Lyckades avl\u00e4nka %(name)s.",
    "Successfully unlinked the device.": "Lyckades avl\u00e4nka enheten",
    "Successfully unshared library {placeholder}": "Slutade dela bibliotek {placeholder}",
    "Successfully unshared {name}": "Lyckades avl\u00e4nka {name}",
    "Successfully unstarred {library_name_placeholder}.": "{library_name_placeholder} togs bort fr\u00e5n favoriter.",
    "Suggestion": "F\u00f6rslag",
    "Switch sort mode": "Switch sort mode",
    "Switch to plain text editor": "Byt till enkel textredigerare",
    "Switch to rich text editor": "Byt till ut\u00f6kad textredigerare",
    "Switch view mode": "Switch view mode",
    "Sync": "Synka",
    "Sync Download": "Synk-nedladdning",
    "Sync Traffic": "Synk Trafik",
    "Sync Upload": "Synk-uppladdning",
    "System": "System",
    "System Admin": "Systemadmin",
    "System Info": "Systeminformation",
    "System settings updated": "System settings updated",
    "Table": "Tabell",
    "Tag not found": "Inga alternativ tillg\u00e4ngliga",
    "Tagged Files": "Taggade Filer",
    "Tags": "Taggar",
    "Team name": "Team name",
    "Template": "Mall",
    "Terms": "Villkor",
    "Terms and Conditions": "Villkor",
    "Text": "Text",
    "Text is required.": "Text kr\u00e4vs.",
    "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved": "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved",
    "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved": "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved",
    "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.": "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.",
    "The file is too large. Allowed maximum size is 1MB.": "Denna fil \u00e4r f\u00f6r stor. Till\u00e5ten maxstorlek \u00e4r 1MB.",
    "The imported options are invalid": "The imported options are invalid",
    "The least number of characters a share/upload link password should include.": "The least number of characters a share/upload link password should include.",
    "The least number of characters an encrypted library password should include.": "Det l\u00e4gsta antal tecken som ett krypterat biblioteks l\u00f6senord ska inneh\u00e5lla.",
    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols",
    "The link is copied to the clipboard.": "L\u00e4nken \u00e4r kopierad till urklipp.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "Lista med tillagda, borttagna och \u00e4ndrade filer har skickats till din maill\u00e5da.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Maximalt antal misslyckade inloggningar innan en CAPTCHA visas.",
    "The name \"{name}\" is already taken. Please choose a different name.": "Namnet \"{name}\" anv\u00e4nds redan. V\u00e4lj ett annat namn.",
    "The next month": "The next month",
    "The next numbers of days": "The next numbers of days",
    "The next week": "The next week",
    "The next year": "The next year",
    "The owner of this library has run out of space.": "\u00c4garen av denna katalog har slut p\u00e5 ledigt diskutrymme.",
    "The password is too short.": "The password is too short.",
    "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.": "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.",
    "The password will be kept in the server for only 1 hour.": "L\u00f6senordet kommer sparas p\u00e5 servern endast en timme",
    "The past month": "The past month",
    "The past numbers of days": "The past numbers of days",
    "The past week": "The past week",
    "The past year": "The past year",
    "There is another option with this name": "There is another option with this name",
    "There is another property with this name": "There is another property with this name",
    "There is no information to display.": "There is no information to display.",
    "This file has (apparently) not been accessed yet": "Filen har (tydligen) inte \u00f6ppnats \u00e4nnu",
    "This file has been updated.": "Denna fil har blivit uppdaterad.",
    "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This folder has no content at this time.": "Denna mapp har inget inneh\u00e5ll just nu.",
    "This is a special group representing a department.": "Detta \u00e4r en speciell grupp som representerar en avdelning.",
    "This is required": "This is required",
    "This library has been set to read-only by admin and cannot be updated.": "Denna katalog har satts med enbart l\u00e4s r\u00e4ttigheter av admin och kan inte uppdateras.",
    "This library has been shared to {user_amount} user(s) and {group_amount} group(s).": "This library has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This library is password protected": "Katalogen \u00e4r l\u00f6senordsskyddad",
    "This month": "This month",
    "This operation will not be reverted. Please think twice!": "Denna \u00e5tg\u00e4rd kan inte \u00e5ngras. T\u00e4nk efter innan!",
    "This property can not be deleted": "This property can not be deleted",
    "This property does not support sorting": "This property does not support sorting",
    "This property is not editable": "This property is not editable",
    "This user has not created or joined any groups": "Denna anv\u00e4ndare har inte skapat eller g\u00e5tt med n\u00e5gra grupper",
    "This week": "This week",
    "This year": "This year",
    "Thumbnail": "Thumbnail",
    "Time": "Tid",
    "Tip: -2 means no limit.": "Tips: -2 betyder ingen begr\u00e4nsning.",
    "Tip: 0 means default limit": "Tips: 0 betyder standardbegr\u00e4nsning",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tips: En \u00f6gonblicksbild kommer skapas efter f\u00f6r\u00e4ndring, vilket sparar bibliotekets tillst\u00e5nd efter f\u00f6r\u00e4ndringen.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tips: kataloger som \u00e4r borttagna f\u00f6r {placeholder} dagar sedan kommer rensas automatiskt.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tips: kataloger borttagna {trashReposExpireDays} dagar sedan kommer rensas automatiskt.",
    "Tip: you can search by keyword in name or ID.": "Tip: you can search by keyword in name or ID.",
    "Tip: you can search by keyword in name.": "Tips: du kan s\u00f6ka genom att ange nyckelord namnet.",
    "Today": "Today",
    "Token": "K\u00e4nnetecken",
    "Token:": "Token:",
    "Tomorrow": "Tomorrow",
    "Too many requests": "Too many requests",
    "Total Devices": "Total Enheter",
    "Total Storage": "Total Yta",
    "Total Traffic": "Total trafik",
    "Total Users": "Totalt antal anv\u00e4ndare",
    "Traffic": "Trafik",
    "Transfer": "\u00d6verf\u00f6r",
    "Transfer Group": "\u00d6verf\u00f6r grupp",
    "Transfer Group {placeholder} to": "\u00d6verf\u00f6r Grupp {placeholder} till",
    "Transfer Library": "\u00d6verf\u00f6r bibliotek",
    "Transfer Library {library_name}": "\u00d6verf\u00f6r Katalogen {library_name}",
    "Transfer group to": "\u00d6verf\u00f6r grupp till",
    "Transfer to department": "\u00d6verf\u00f6r till avdelning",
    "Transfer to user": "\u00d6verf\u00f6r till anv\u00e4ndare",
    "Transferred group {group_name} from {user_from} to {user_to}": "\u00d6verf\u00f6rde grupp {group_name} fr\u00e5n {user_from} till {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "\u00d6verf\u00f6rde bibliotek {library_name} fr\u00e5n {user_from} till {user_to}",
    "Trash": "Papperskorg",
    "Turn off": "Turn off",
    "Turn off extended properties": "Turn off extended properties",
    "Turn on extensible properties and views to experience a new way of managing files": "Turn on extensible properties and views to experience a new way of managing files",
    "Two-Factor Authentication": "Tv\u00e5faktorsautentisering",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "Tv\u00e5faktorsautentisering \u00e4r inte till\u00e5ten f\u00f6r ditt konto. Aktivera tv\u00e5faktorsautentisering f\u00f6r h\u00f6gre kontos\u00e4kerhet.",
    "Type": "Typ",
    "Type characters to start search": "Type characters to start search",
    "URL is copied to the clipboard": "URL is copied to the clipboard",
    "URL is required": "URL is required",
    "US": "US",
    "Undo": "Undo",
    "Unfreeze Document": "Unfreeze Document",
    "Unhandled": "Ohanterad",
    "Unknown": "Ok\u00e4nd",
    "Unlink": "Avl\u00e4nka",
    "Unlink device": "Avl\u00e4nka enhet",
    "Unlock": "L\u00e5s upp",
    "Unpublish": "Avpublicera",
    "Unresolved comments": "Ol\u00f6sta kommentarer",
    "Unselect": "Unselect",
    "Unshare": "Sluta dela",
    "Unshare Library": "Sluta dela bibliotek",
    "Unstar": "Ta bort favorit",
    "Untitled": "Untitled",
    "Unwatch File Changes": "Unwatch File Changes",
    "Up": "Upp",
    "Update": "Uppdatera",
    "Update Terms and Conditions": "Uppdatera villkor",
    "Update password": "Update password",
    "Update succeeded.": "Uppdatering lyckades.",
    "Updated draft": "Uppdaterat utkast",
    "Updated file": "Uppdaterat fil",
    "Upgrade to Pro Edition": "Uppgradera till Pro Edition",
    "Upload": "Ladda upp",
    "Upload Files": "Ladda upp filer",
    "Upload Folder": "Ladda upp mapp",
    "Upload Link": "Uppladdningsl\u00e4nk",
    "Upload Links": "Uppladdningsl\u00e4nkar",
    "Upload file": "Ladda upp fil",
    "Upload license": "Ladda upp licens",
    "Upload link is copied to the clipboard.": "Uppladdnignsl\u00e4nk kopierad till urklipp.",
    "Uploaded": "Uppladdad",
    "Uploading...": "Uploading...",
    "Use custom CSS": "Anv\u00e4nds egen CSS",
    "Use information from your Identity Provider to configure Seafile": "Use information from your Identity Provider to configure Seafile",
    "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.": "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.",
    "Use these values to configure your Identity Provider": "Use these values to configure your Identity Provider",
    "Used:": "Anv\u00e4nt",
    "User": "Anv\u00e4ndare",
    "User Email": "Anv\u00e4ndarmail",
    "User Permission": "Anv\u00e4ndarr\u00e4ttigheter",
    "User Shares": "User Shares",
    "User Storage": "Anv\u00e4ndarutrymme",
    "User can not see this folder.": "User can not see this folder.",
    "User can only view files online via browser. Files can't be downloaded.": "Anv\u00e4ndare kan se filer online via webbl\u00e4saren. Filer kan inte laddas ned.",
    "User can read, download and sync files.": "Anv\u00e4ndare kan l\u00e4sa, ladda ned och synka filer.",
    "User can read, write, upload, download and sync files.": "Anv\u00e4ndare kan l\u00e4sa, skriva, ladda upp, ladda ned och synka filer.",
    "User can view and edit file online via browser. Files can't be downloaded.": "Anv\u00e4ndare kan l\u00e4sa och redigera filer online via webbl\u00e4saren. Filer kan inte laddas ned.",
    "User info updated": "User info updated",
    "User migrate from {user_from} to {user_to}": "User migrate from {user_from} to {user_to}",
    "User not found": "Anv\u00e4ndare hittades inte",
    "User {user_link} has added you to {group_link}": "Anv\u00e4ndaren {user_link} har lagt till dig till {group_link}",
    "Username:": "Anv\u00e4ndarnamn:",
    "Users": "Anv\u00e4ndare",
    "Verified": "Verified",
    "Verify": "Verifiera",
    "Verify Domain": "Verify Domain",
    "Version": "Version",
    "Version Number": "Versions Nummer",
    "Version Number is required.": "Versionsnummer kr\u00e4vs.",
    "Version Number must be a number.": "Versionsnummer m\u00e5ste vara en siffra.",
    "Video": "Video",
    "View": "Visa",
    "View Link": "Visa L\u00e4nk",
    "View Related Snapshot": "View Related Snapshot",
    "View Snapshot": "Visa Snapshot",
    "View profile and more": "Visa profil och mer",
    "Views": "Views",
    "Virus": "Virus",
    "Virus File": "Virusfil",
    "Virus Scan": "Virusscan",
    "Visit count": "Visit count",
    "Visit old version page": "Visit old version page",
    "Visited": "Bes\u00f6kte",
    "Visits": "Bes\u00f6k",
    "Watch File Changes": "Watch File Changes",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Webb-nedladdning",
    "Web Traffic": "Webb Trafik",
    "Web Upload": "Webb-uppladdning",
    "WebDAV Access": "WebDAV Access",
    "WebDAV password:": "WebDAV password:",
    "WebDAV username:": "WebDAV username:",
    "Welcome to {site_name_placeholder}": "V\u00e4lkommen till {site_name_placeholder}",
    "Wiki custom URL deleted": "Wiki custom URL deleted",
    "Wiki owner": "Wiki owner",
    "Wiki published": "Wiki published",
    "Wikis": "Wikis",
    "Wrong password": "Fel l\u00f6senord",
    "Year": "Year",
    "Yesterday": "Yesterday",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Du kan ocks\u00e5 l\u00e4gga till en anv\u00e4ndare som g\u00e4st, som inte kommer kunna skapa kataloger eller grupper.",
    "You can create files quickly": "Du kan skapa filer snabbt",
    "You can enter multiple emails. An invitation link will be sent to each of them.": "You can enter multiple emails. An invitation link will be sent to each of them.",
    "You can use this field at login.": "Du kan anv\u00e4nda detta f\u00e4lt vid inloggning.",
    "You do not have permission": "You do not have permission",
    "You don't have any favorite items yet": "Du har inga favoritobjekt \u00e4nnu",
    "You don't have any share links": "Du har inga delningsl\u00e4nkgar",
    "You don't have any upload links": "Du har inga uppladdningsl\u00e4nkar",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "Du har inte \u00f6ppnat dina filer med n\u00e5gon klient (skrivbord eller mobil) \u00e4nnu. Konfigurera klienter p\u00e5 dina enheter f\u00f6r att komma \u00e5t din data enklare.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "Du har inte lagt till n\u00e5gra kataloger, mappar eller filer till dina favoriter \u00e4nnu. En favorit ger dig snabbt \u00e5tkomst till dina mest frekvent anv\u00e4nda objekt. Du kan l\u00e4gga till en katalog, mapp eller fil till dina favoriter genom att klicka p\u00e5 stj\u00e4rnan till v\u00e4nster om dess namn.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "Du har inte skapat n\u00e5gra delningsl\u00e4nkar \u00e4nnu. En delningsl\u00e4nk kan anv\u00e4ndas av anv\u00e4ndare till att dela filer och mappar med vem som helst. Du kan skapa en delningsl\u00e4nk f\u00f6r en fil eller mapp genom att klicka p\u00e5 delningsikonen till h\u00f6ger om dess namn.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "Du har inte skapat en uppladdningsl\u00e4nk \u00e4nnu. En uppladdningsl\u00e4nk till\u00e5ter vem som helst att ladda upp filer till en mapp eller katalog. Du kan skapa en uppladdningsl\u00e4nk f\u00f6r en mapp eller katalog genom att klicka p\u00e5 delningsikonen till h\u00f6ger om dess namn.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "Du har inte tagit bort n\u00e5gra kataloger de senaste {placeholder} dagar. En borttagen katalog kommer att rensas automatiskt efter denna period.",
    "You have not shared any folders": "Du har inte delat n\u00e5gra mappar",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "Du har inte delat n\u00e5gra mappar med andra anv\u00e4ndare \u00e4nnu. Du kan dela en mapp med andra anv\u00e4ndare genom att klicka p\u00e5 delningsikonen till h\u00f6ger om en mapps namn.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "Du har inte delat n\u00e5gra kataloger med andra anv\u00e4ndare \u00e4nnu. Du kan dela en katalog med andra anv\u00e4ndare genom att klicka p\u00e5 dela ikonen till h\u00f6ger om en katalogs namn i \"Mina Kataloger\".",
    "You have only one backup code remaining.": "Du har bara en backupkod kvar.",
    "You have {num} backup codes remaining.": "Du har {num} backupkoder kvar.",
    "Your notifications will be sent to this email.": "Dina notifikationer kommer att skickas till denna mejladress.",
    "ZIP": "ZIP",
    "Zoom in": "Zooma in",
    "Zoom out": "Zooma ut",
    "all": "alla",
    "all members": "alla medlemmar",
    "contains": "Inneh\u00e5ller",
    "days": "dagar",
    "deleted": "borttagen",
    "deleted option": "deleted option",
    "details": "detaljer",
    "does not contain": "Inneh\u00e5ller inte",
    "email is required": "mailadress kr\u00e4vs",
    "freezed": "freezed",
    "has all of...": "has all of...",
    "has any of...": "has any of...",
    "has none of...": "has none of...",
    "icon": "ikon",
    "in all libraries": "in all libraries",
    "include the current user": "Inkludera mig",
    "is": "\u00c4r",
    "is after...": "is after...",
    "is any of...": "is any of...",
    "is before...": "is before...",
    "is current user's ID": "\u00c4r nuvarande anv\u00e4ndar-ID",
    "is empty": "Tom",
    "is exactly...": "is exactly...",
    "is none of...": "is none of...",
    "is not": "\u00c4r inte",
    "is not empty": "Icke tom",
    "is on or after...": "is on or after...",
    "is on or before...": "is on or before...",
    "is within...": "is within...",
    "items": "items",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensierad till {placeholder_license_to}, l\u00f6per ut {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensierad till {placeholder_license_to}, uppgraderingsservice l\u00f6per ut {placeholder_license_expiration}",
    "locked": "l\u00e5st",
    "locked by {name}": "l\u00e4st av {name}",
    "mm": "mm",
    "name": "namn",
    "not set": "not set",
    "only show {placeholder}": "only show {placeholder}",
    "progress": "g\u00e5ng",
    "s": "s",
    "selected": "selected",
    "show more": "visa mer",
    "size": "storlek",
    "sorts": "Sorteringar",
    "starred": "favorit skapad",
    "state": "tillst\u00e5nd",
    "successfully added user %s.": "lyckades l\u00e4gga till anv\u00e4ndare %s.",
    "successfully sent email to %s.": "successfully sent email to %s.",
    "unstarred": "favorit borttagen",
    "xxx cells copied": "xxx cells copied",
    "xxx cells selected": "xxx cells selected",
    "xxx record": "xxx record",
    "xxx records": "xxx records",
    "xxx records selected": "xxx records selected",
    "xxx rows are copied.": "xxx rows are copied.",
    "you can also press \u2192": "du kan ocks\u00e5 trycka \u2192",
    "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
    "{file} and {n} other files": "{file} och {n} andra filer",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} dagar",
    "{number_placeholder} / Page": "{number_placeholder} / Sida",
    "{placeholder} API Token": "{placeholder} API Token",
    "{placeholder} Access Log": "{placeholder} Access Log",
    "{placeholder} Folder Permission": "{placeholder} Mappr\u00e4ttigheter",
    "{placeholder} History Setting": "{placeholder} Historikinst\u00e4llning",
    "{placeholder} Modification History": "{placeholder} \u00c4ndringshistorik",
    "{placeholder} Share Admin": "{placeholder} Share Admin",
    "{placeholder} Snapshot": "{placeholder} \u00d6gonblicksbild",
    "{placeholder} Trash": "{placeholder} Papperskorg",
    "{placeholder} Wiki Trash": "{placeholder} Wiki Trash",
    "{share_from} has cancelled the sharing of folder {repo_name}.": "{share_from} has cancelled the sharing of folder {repo_name}.",
    "{share_from} has cancelled the sharing of library {repo_name}.": "{share_from} has cancelled the sharing of library {repo_name}.",
    "{share_from} has changed the permission of folder {repo_link} to {permission}.": "{share_from} has changed the permission of folder {repo_link} to {permission}.",
    "{share_from} has changed the permission of library {repo_link} to {permission}.": "{share_from} has changed the permission of library {repo_link} to {permission}.",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} har delat mappen med namnet {repo_link} till gruppen {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} har delat en mapp med namnet {repo_link} med dig.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} har delat en katalog med namnet {repo_link} till gruppen {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} har delat katalogen {repo_link} till dig.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. However, since you are a guest user now, you can not create libraries.": "{site_name_placeholder} organiserar filer in i kataloger. Varje katalog kan synkroniseras och delas separat. Men, eftersom du \u00e4r en g\u00e4stanv\u00e4ndare, s\u00e5 kan du inte skapa kataloger.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. We have created a personal library for you. You can create more libraries later.": "{site_name_placeholder} organiserar filer in i kataloger. Varje katalog kan synkroniseras och delas separat. Vi har skapat en personlig katalog \u00e5t dig. Du kan skapa fler kataloger senare.",
    "{uploaded_files_num}/{all_files_num} Files": "{uploaded_files_num}/{all_files_num} Files",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} anv\u00e4ndare och {repoCount} kataloger i denna organisation kommer ocks\u00e5 att tas bort.",
    "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} created file {fileName} in library {libraryName}.": "{user} created file {fileName} in library {libraryName}.",
    "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} created folder {folderName} in library {libraryName}.": "{user} created folder {folderName} in library {libraryName}.",
    "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} deleted file {fileName} in library {libraryName}.": "{user} deleted file {fileName} in library {libraryName}.",
    "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} deleted folder {folderName} in library {libraryName}.": "{user} deleted folder {folderName} in library {libraryName}.",
    "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} moved file {fileName} in library {libraryName}.": "{user} moved file {fileName} in library {libraryName}.",
    "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} moved folder {folderName} in library {libraryName}.": "{user} moved folder {folderName} in library {libraryName}.",
    "{user} renamed file {oldFileName} {fileName} in library {libraryName}.": "{user} renamed file {oldFileName} {fileName} in library {libraryName}.",
    "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.": "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.",
    "{user} restored file {fileName} in library {libraryName}.": "{user} restored file {fileName} in library {libraryName}.",
    "{user} restored folder {folderName} in library {libraryName}.": "{user} restored folder {folderName} in library {libraryName}.",
    "{user} updated file {fileName} in library {libraryName}.": "{user} updated file {fileName} in library {libraryName}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "j F Y H:i",
    "DATETIME_INPUT_FORMATS": [
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%m/%d/%Y %H:%M:%S",
      "%m/%d/%Y %H:%M:%S.%f",
      "%m/%d/%Y %H:%M",
      "%m/%d/%y %H:%M:%S",
      "%m/%d/%y %H:%M:%S.%f",
      "%m/%d/%y %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "j F Y",
    "DATE_INPUT_FORMATS": [
      "%Y-%m-%d",
      "%m/%d/%Y",
      "%m/%d/%y"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "j F",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "Y-m-d H:i",
    "SHORT_DATE_FORMAT": "Y-m-d",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M:%S.%f",
      "%H:%M"
    ],
    "YEAR_MONTH_FORMAT": "F Y"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

